Stan Math Library: stan/math/prim/scal/fun/log1m.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log1m.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOG1M_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOG1M_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/scal/fun/log1p.hpp>
6
7 namespace stan {
8 namespace math {
9
38 template <typename T>
39 inline typename boost::math::tools::promote_args<T>::type
40 log1m(T x) {
41 return log1p(-x);
42 }
43
44 }
45 }
46
47 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::log1p
fvar< T > log1p(const fvar< T > &x)
Definition: log1p.hpp:16
log1p.hpp
stan::math::log1m
fvar< T > log1m(const fvar< T > &x)
Definition: log1m.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.